@@ -11,7 +11,7 @@ use strict;
 use warnings;
 
 package Mail::DKIM::DkPolicy;
-use base "Mail::DKIM::Policy";
+use base 'Mail::DKIM::Policy';
 use Mail::DKIM::DNS;
 
 =head1 NAME
@@ -30,7 +30,7 @@ DNS that describes how they sign messages.
 =head2 fetch() - fetch a sender signing policy from DNS
 
   my $policy = Mail::DKIM::DkPolicy->fetch(
-                   Protocol => "dns",
+                   Protocol => 'dns',
                    Sender => 'joe@example.org',
                );
 
@@ -75,35 +75,32 @@ To check when this happens, use
 
 # get_lookup_name() - determine name of record to fetch
 #
-sub get_lookup_name
-{
-	my $self = shift;
-	my ($prms) = @_;
+sub get_lookup_name {
+    my $self = shift;
+    my ($prms) = @_;
 
-	# in DomainKeys, the record to fetch is determined based on the
-	# Sender header, then the From header
+    # in DomainKeys, the record to fetch is determined based on the
+    # Sender header, then the From header
 
-	if ($prms->{Author} && !$prms->{Sender})
-	{
-		$prms->{Sender} = $prms->{Author};
-	}
-	if ($prms->{Sender} && !$prms->{Domain})
-	{
-		# pick domain from email address
-		$prms->{Domain} = ($prms->{Sender} =~ /\@([^@]*)$/ and $1);
-	}
+    if ( $prms->{Author} && !$prms->{Sender} ) {
+        $prms->{Sender} = $prms->{Author};
+    }
+    if ( $prms->{Sender} && !$prms->{Domain} ) {
 
-	unless ($prms->{Domain})
-	{
-		die "no domain to fetch policy for\n";
-	}
+        # pick domain from email address
+        $prms->{Domain} = ( $prms->{Sender} =~ /\@([^@]*)$/ and $1 );
+    }
 
-	# IETF seems poised to create policy records this way
-	#my $host = "_policy._domainkey." . $prms{Domain};
+    unless ( $prms->{Domain} ) {
+        die "no domain to fetch policy for\n";
+    }
 
-	# but Yahoo! policy records are still much more common
-	# see historic RFC4870, section 3.6
-	return "_domainkey." . $prms->{Domain};
+    # IETF seems poised to create policy records this way
+    #my $host = '_policy._domainkey.' . $prms{Domain};
+
+    # but Yahoo! policy records are still much more common
+    # see historic RFC4870, section 3.6
+    return '_domainkey.' . $prms->{Domain};
 }
 
 =head2 new() - construct a default policy object
@@ -112,27 +109,26 @@ sub get_lookup_name
 
 =cut
 
-sub new
-{
-	my $class = shift;
-	return $class->parse(String => "o=~");
+sub new {
+    my $class = shift;
+    return $class->parse( String => 'o=~' );
 }
 
 =head2 parse() - gets a policy object by parsing a string
 
   my $policy = Mail::DKIM::DkPolicy->parse(
-                   String => "o=~; t=y"
+                   String => 'o=~; t=y'
                );
 
 =cut
 
 #undocumented private class method
 our $DEFAULT_POLICY;
-sub default
-{
-	my $class = shift;
-	$DEFAULT_POLICY ||= $class->new;
-	return $DEFAULT_POLICY;
+
+sub default {
+    my $class = shift;
+    $DEFAULT_POLICY ||= $class->new;
+    return $DEFAULT_POLICY;
 }
 
 =head1 METHODS
@@ -165,28 +161,26 @@ policy. It can be considered suspicious.
 
 =cut
 
-sub apply
-{
-	my $self = shift;
-	my ($dkim) = @_;
+sub apply {
+    my $self = shift;
+    my ($dkim) = @_;
 
-	my $first_party;
-	foreach my $signature ($dkim->signatures)
-	{
-		next if $signature->result ne "pass";
+    my $first_party;
+    foreach my $signature ( $dkim->signatures ) {
+        next if $signature->result ne 'pass';
 
-		my $oa = $dkim->message_sender->address;
-		if ($signature->identity_matches($oa))
-		{
-			# found a first party signature
-			$first_party = 1;
-			last;
-		}
-	}
+        my $oa = $dkim->message_sender->address;
+        if ( $signature->identity_matches($oa) ) {
 
-	return "accept" if $first_party;
-	return "reject" if ($self->signall && !$self->testing);
-	return "neutral";
+            # found a first party signature
+            $first_party = 1;
+            last;
+        }
+    }
+
+    return 'accept' if $first_party;
+    return 'reject' if ( $self->signall && !$self->testing );
+    return 'neutral';
 }
 
 =head2 flags() - get or set the flags (t=) tag
@@ -195,14 +189,13 @@ A vertical-bar separated list of flags.
 
 =cut
 
-sub flags
-{
-	my $self = shift;
+sub flags {
+    my $self = shift;
 
-	(@_) and 
-		$self->{tags}->{t} = shift;
+    (@_)
+      and $self->{tags}->{t} = shift;
 
-	$self->{tags}->{t};
+    $self->{tags}->{t};
 }
 
 =head2 is_implied_default_policy() - is this policy implied?
@@ -215,11 +208,10 @@ in effect. Use this method to detect when that happens.
 
 =cut
 
-sub is_implied_default_policy
-{
-	my $self = shift;
-	my $default_policy = ref($self)->default;
-	return ($self == $default_policy);
+sub is_implied_default_policy {
+    my $self           = shift;
+    my $default_policy = ref($self)->default;
+    return ( $self == $default_policy );
 }
 
 =head2 location() - where the policy was fetched from
@@ -232,9 +224,8 @@ was returned instead, the location will be C<undef>.
 
 =cut
 
-sub name
-{
-	return "sender";
+sub name {
+    return 'sender';
 }
 
 =head2 note() - get or set the human readable notes (n=) tag
@@ -243,14 +234,13 @@ Human readable notes regarding the record. Undef if no notes specified.
 
 =cut
 
-sub note
-{
-	my $self = shift;
+sub note {
+    my $self = shift;
 
-	(@_) and 
-		$self->{tags}->{n} = shift;
+    (@_)
+      and $self->{tags}->{n} = shift;
 
-	$self->{tags}->{n};
+    $self->{tags}->{n};
 }
 
 =head2 policy() - get or set the outbound signing policy (o=) tag
@@ -273,44 +263,39 @@ The domain signs all email.
 
 =cut
 
-sub policy
-{
-	my $self = shift;
+sub policy {
+    my $self = shift;
 
-	(@_) and
-		$self->{tags}->{o} = shift;
+    (@_)
+      and $self->{tags}->{o} = shift;
 
-	if (defined $self->{tags}->{o})
-	{
-		return $self->{tags}->{o};
-	}
-	else
-	{
-		return "~"; # the default
-	}
+    if ( defined $self->{tags}->{o} ) {
+        return $self->{tags}->{o};
+    }
+    else {
+        return '~';    # the default
+    }
 }
 
-=head2 signall() - true if policy is "-"
+=head2 signall() - true if policy is /-"
 
 =cut
 
-sub signall
-{
-	my $self = shift;
-	return ($self->policy && $self->policy eq "-");
+sub signall {
+    my $self = shift;
+    return ( $self->policy && $self->policy eq '-' );
 }
 
-sub signsome
-{
-	my $self = shift;
+sub signsome {
+    my $self = shift;
 
-	$self->policy or
-		return 1;
+    $self->policy
+      or return 1;
 
-	$self->policy eq "~" and
-		return 1;
+    $self->policy eq '~'
+      and return 1;
 
-	return;
+    return;
 }
 
 =head2 testing() - checks the testing flag
@@ -322,13 +307,12 @@ verify should not consider a message suspicious based on this policy.
 
 =cut
 
-sub testing
-{
-	my $self = shift;
-	my $t = $self->flags;
-	($t && $t =~ /y/i)
-		and return 1;
-	return;
+sub testing {
+    my $self = shift;
+    my $t    = $self->flags;
+    ( $t && $t =~ /y/i )
+      and return 1;
+    return;
 }
 
 1;
